Class: Fastlane::Actions::FivBuildIonicAndroidAction
- Inherits:
-
Action
- Object
- Action
- Fastlane::Actions::FivBuildIonicAndroidAction
- Defined in:
- lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb
Documentation collapse
- .authors ⇒ Object
- .available_options ⇒ Object
- .description ⇒ Object
- .details ⇒ Object
- .is_supported?(platform) ⇒ Boolean
- .output ⇒ Object
- .return_value ⇒ Object
Class Method Summary collapse
Class Method Details
.authors ⇒ Object
62 63 64 65 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 62 def self. # So no one will ever forget your contribution to fastlane :) You are awesome btw! ['Your GitHub/Twitter Name'] end |
.available_options ⇒ Object
32 33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 32 def self. # Define all options your action supports. # Below a few examples [ FastlaneCore::ConfigItem.new( key: :isProd, env_name: 'FIV_BUILD_IONIC_ANDROID_IS_PROD', description: 'Dev or Prod build', optional: false, type: Boolean ) ] end |
.description ⇒ Object
22 23 24 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 22 def self.description 'A short description with <= 80 characters of what this action does' end |
.details ⇒ Object
26 27 28 29 30 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 26 def self.details # Optional: # this is your chance to provide a more detailed description of this action 'You can use this action to do cool things...' end |
.is_supported?(platform) ⇒ Boolean
67 68 69 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 67 def self.is_supported?(platform) platform == :android end |
.output ⇒ Object
47 48 49 50 51 52 53 54 55 56 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 47 def self.output # Define the shared values you are going to provide # Example [ [ 'FIV_BUILD_IONIC_ANDROID_CUSTOM_VALUE', 'A description of what this value contains' ] ] end |
.return_value ⇒ Object
58 59 60 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 58 def self.return_value # If your method provides a return value, you can describe here what it does end |
.run(params) ⇒ Object
9 10 11 12 13 14 15 16 |
# File 'lib/fastlane/plugin/fivethree_ionic/actions/fiv_build_ionic_android.rb', line 9 def self.run(params) isProd = params[:isProd] if (isProd) sh 'ionic cordova build android --prod' else sh 'ionic cordova build android' end end |